# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["ListDeleteResponse"]


class ListDeleteResponse(BaseModel):
    id: str
    """The unique ID of the list."""
