# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...pagination import SyncSinglePage, AsyncSinglePage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.tenant_custom_nameservers import tenant_custom_nameserver_create_params
from ...types.tenant_custom_nameservers.tenant_custom_nameserver_get_response import TenantCustomNameserverGetResponse
from ...types.tenant_custom_nameservers.tenant_custom_nameserver_create_response import (
    TenantCustomNameserverCreateResponse,
)
from ...types.tenant_custom_nameservers.tenant_custom_nameserver_delete_response import (
    TenantCustomNameserverDeleteResponse,
)

__all__ = ["TenantCustomNameserversResource", "AsyncTenantCustomNameserversResource"]


class TenantCustomNameserversResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TenantCustomNameserversResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return TenantCustomNameserversResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TenantCustomNameserversResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return TenantCustomNameserversResourceWithStreamingResponse(self)

    def create(
        self,
        tenant_tag: str,
        *,
        ns_name: str,
        ns_set: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TenantCustomNameserverCreateResponse]:
        """
        Add Tenant Custom Nameserver

        Args:
          tenant_tag: Tenant identifier tag.

          ns_name: The FQDN of the name server.

          ns_set: The number of the set that this name server belongs to.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        return self._post(
            path_template("/tenants/{tenant_tag}/custom_ns", tenant_tag=tenant_tag),
            body=maybe_transform(
                {
                    "ns_name": ns_name,
                    "ns_set": ns_set,
                },
                tenant_custom_nameserver_create_params.TenantCustomNameserverCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TenantCustomNameserverCreateResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[TenantCustomNameserverCreateResponse]],
                ResultWrapper[TenantCustomNameserverCreateResponse],
            ),
        )

    def delete(
        self,
        custom_ns_id: str,
        *,
        tenant_tag: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[TenantCustomNameserverDeleteResponse]:
        """
        Delete Tenant Custom Nameserver

        Args:
          tenant_tag: Tenant identifier tag.

          custom_ns_id: The FQDN of the name server.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        if not custom_ns_id:
            raise ValueError(f"Expected a non-empty value for `custom_ns_id` but received {custom_ns_id!r}")
        return self._get_api_list(
            path_template(
                "/tenants/{tenant_tag}/custom_ns/{custom_ns_id}", tenant_tag=tenant_tag, custom_ns_id=custom_ns_id
            ),
            page=SyncSinglePage[TenantCustomNameserverDeleteResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=str,
            method="delete",
        )

    def get(
        self,
        tenant_tag: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[TenantCustomNameserverGetResponse]:
        """
        List a tenant's custom nameservers.

        Args:
          tenant_tag: Tenant identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        return self._get_api_list(
            path_template("/tenants/{tenant_tag}/custom_ns", tenant_tag=tenant_tag),
            page=SyncSinglePage[TenantCustomNameserverGetResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=TenantCustomNameserverGetResponse,
        )


class AsyncTenantCustomNameserversResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTenantCustomNameserversResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTenantCustomNameserversResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTenantCustomNameserversResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncTenantCustomNameserversResourceWithStreamingResponse(self)

    async def create(
        self,
        tenant_tag: str,
        *,
        ns_name: str,
        ns_set: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[TenantCustomNameserverCreateResponse]:
        """
        Add Tenant Custom Nameserver

        Args:
          tenant_tag: Tenant identifier tag.

          ns_name: The FQDN of the name server.

          ns_set: The number of the set that this name server belongs to.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        return await self._post(
            path_template("/tenants/{tenant_tag}/custom_ns", tenant_tag=tenant_tag),
            body=await async_maybe_transform(
                {
                    "ns_name": ns_name,
                    "ns_set": ns_set,
                },
                tenant_custom_nameserver_create_params.TenantCustomNameserverCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[TenantCustomNameserverCreateResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[TenantCustomNameserverCreateResponse]],
                ResultWrapper[TenantCustomNameserverCreateResponse],
            ),
        )

    def delete(
        self,
        custom_ns_id: str,
        *,
        tenant_tag: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[TenantCustomNameserverDeleteResponse, AsyncSinglePage[TenantCustomNameserverDeleteResponse]]:
        """
        Delete Tenant Custom Nameserver

        Args:
          tenant_tag: Tenant identifier tag.

          custom_ns_id: The FQDN of the name server.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        if not custom_ns_id:
            raise ValueError(f"Expected a non-empty value for `custom_ns_id` but received {custom_ns_id!r}")
        return self._get_api_list(
            path_template(
                "/tenants/{tenant_tag}/custom_ns/{custom_ns_id}", tenant_tag=tenant_tag, custom_ns_id=custom_ns_id
            ),
            page=AsyncSinglePage[TenantCustomNameserverDeleteResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=str,
            method="delete",
        )

    def get(
        self,
        tenant_tag: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[TenantCustomNameserverGetResponse, AsyncSinglePage[TenantCustomNameserverGetResponse]]:
        """
        List a tenant's custom nameservers.

        Args:
          tenant_tag: Tenant identifier tag.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not tenant_tag:
            raise ValueError(f"Expected a non-empty value for `tenant_tag` but received {tenant_tag!r}")
        return self._get_api_list(
            path_template("/tenants/{tenant_tag}/custom_ns", tenant_tag=tenant_tag),
            page=AsyncSinglePage[TenantCustomNameserverGetResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=TenantCustomNameserverGetResponse,
        )


class TenantCustomNameserversResourceWithRawResponse:
    def __init__(self, tenant_custom_nameservers: TenantCustomNameserversResource) -> None:
        self._tenant_custom_nameservers = tenant_custom_nameservers

        self.create = to_raw_response_wrapper(
            tenant_custom_nameservers.create,
        )
        self.delete = to_raw_response_wrapper(
            tenant_custom_nameservers.delete,
        )
        self.get = to_raw_response_wrapper(
            tenant_custom_nameservers.get,
        )


class AsyncTenantCustomNameserversResourceWithRawResponse:
    def __init__(self, tenant_custom_nameservers: AsyncTenantCustomNameserversResource) -> None:
        self._tenant_custom_nameservers = tenant_custom_nameservers

        self.create = async_to_raw_response_wrapper(
            tenant_custom_nameservers.create,
        )
        self.delete = async_to_raw_response_wrapper(
            tenant_custom_nameservers.delete,
        )
        self.get = async_to_raw_response_wrapper(
            tenant_custom_nameservers.get,
        )


class TenantCustomNameserversResourceWithStreamingResponse:
    def __init__(self, tenant_custom_nameservers: TenantCustomNameserversResource) -> None:
        self._tenant_custom_nameservers = tenant_custom_nameservers

        self.create = to_streamed_response_wrapper(
            tenant_custom_nameservers.create,
        )
        self.delete = to_streamed_response_wrapper(
            tenant_custom_nameservers.delete,
        )
        self.get = to_streamed_response_wrapper(
            tenant_custom_nameservers.get,
        )


class AsyncTenantCustomNameserversResourceWithStreamingResponse:
    def __init__(self, tenant_custom_nameservers: AsyncTenantCustomNameserversResource) -> None:
        self._tenant_custom_nameservers = tenant_custom_nameservers

        self.create = async_to_streamed_response_wrapper(
            tenant_custom_nameservers.create,
        )
        self.delete = async_to_streamed_response_wrapper(
            tenant_custom_nameservers.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            tenant_custom_nameservers.get,
        )
